#!/bin/bash
# Create all special files for cyclades mux card

dialog --title "CREATING DEVICE FILES" --msgbox "Please press ENTER" 5 40

	mknod /dev/ttyC0 c 19 32 
	mknod /dev/ttyC1 c 19 33
	mknod /dev/ttyC2 c 19 34
	mknod /dev/ttyC3 c 19 35
	mknod /dev/ttyC4 c 19 36
	mknod /dev/ttyC5 c 19 37
	mknod /dev/ttyC6 c 19 38
	mknod /dev/ttyC7 c 19 39

	mknod /dev/cub0 c 20 32
	mknod /dev/cub1 c 20 33
	mknod /dev/cub2 c 20 34
	mknod /dev/cub3 c 20 35
	mknod /dev/cub4 c 20 36
	mknod /dev/cub5 c 20 37
	mknod /dev/cub6 c 20 38
	mknod /dev/cub7 c 20 39

        chmod 666 /dev/ttyC?
        chmod 666 /dev/cub?

# ----------- ownership depends from system to system. Here's mine
#
	chown root:uucp /dev/ttyC?
	chown root:tty /dev/cub?

dialog --title "CREATING DEVICE FILES" --msgbox "DONE !" 5 30
INST_CYCLOM

